Change log for feature-check
============================

2.0.0 - 2022/10/12
------------------

- INCOMPATIBLE CHANGES in the Python and Rust library implementations
  (not in the command-line tools); see below for details.
- Add an EditorConfig definitions file.
- Rust implementation:
  - incompatible changes:
    - the numeric components of version strings are now unsigned (`u32`),
      whereas before a signed integer type (`i32`) was used
    - parse the examined program's features line into `Version` structs
      instead of free-form strings
    - use the `anyhow` and `thiserror` libraries instead of `quick-error`
      and, for the command-line tool, `expect-exit`; the exported enums and
      structs representing errors returned by the library functions have
      been reimplemented
  - refactor a lot according to many suggestions from Clippy
  - add the `run-clippy.sh` tool to run a lot of diagnostic checks
  - use a `Termination` trait for the `main()` exit code and specify
    a minimum Rust version of 1.61
  - bump the version of the `expect-exit` dependency to 0.5 for
    the `bool.or_exit()` implementation
  - use a Nom-based parser for the `featurename` and `featurename op version`
    expressions that may be specified on the command line
  - use a Nom-based parser for the output of the examined program
  - keep the `Cargo.lock` file under version control
  - use the `clap` library for command-line arguments parsing
- Python implementation:
  - incompatible changes:
    - use frozen dataclasses instead of reimplementing them poorly
    - introduce the `.version.VersionComponent` and `.version.Version` classes
      that provide an easy-to-use interface for parsing and comparing version
      strings
    - store a `BoolOp` object directly into the parsed `ExprOp` instead of
      referring to the former by a string name stored in the latter
  - use black 22 for source code formatting, reformat with 100 characters
    per line
  - move the configuration of more static checkers to the `pyproject.toml`
    file
  - bump the minimum supported Python version to 3.7:
    - use deferred type annotations, allowing us to use the lowercase type
      names instead of the `typing` generics
    - use `subprocess.run(capture_output=True)` instead of `Popen`
  - use `pytest.mark.parametrize()` instead of `ddt` for simpler tests
  - use a pyparsing-based parser for the `featurename` and
    `featurename op version` expressions that may be specified on
    the command line
  - use a pyparsing-based parser for the output of the examined program
  - declare Python 3.10 and 3.11 as supported versions
  - drop a `type: ignore` comment for a bug fixed in the `mypy` tool
  - fix the `python/3/feature-check.sh` wrapper so that it does the right
    thing if the `PYTHONPATH` environment variable is already set
- Testing framework:
  - be more permissive when looking for the program's usage message in
    the incorrect command-line options output
  - skip some of the program usage message tests for the Rust implementation,
    too, since the `clap` library can format the text in different ways
  - add Nix shell expressions for running the test suites for the Perl and
    Python implementations in a clean ("pure") Nix environment

1.0.1 - 2021/12/17
------------------

- Use common test definitions for the various implementations,
  generated and kept in sync via the new fcheck-testdata internal tool.
- Python implementation:
  - code clean-up:
    - add a version to the dependency on the "hacking" Python library in
      the tox.ini test definitions to help out pip's resolver
    - use f-strings instead of str.format()
    - use black's default line length of 88 characters
  - add tests for comparisons against beta versions of features
  - actually install the py.typed marker file via the declarative
    setuptools configuration
- Rust implementation:
  - code clean-up:
    - honor clippy's "needless borrow" suggestions
    - add the `html_root_url` doc attribute
    - drop an unused internal structure field
    - get the crate version string from the Cargo manifest, one less place
      to update when bumping the version
    - move the module-level docs after the copyright notices
  - declare compatibility with the Rust 2021 edition with no changes
  - use the quick-error crate instead of writing boilerplate code

1.0.0 - 2021/06/24
------------------
- Perl implementation:
  - fix a 2 < 10 version int/string bug
  - fix a 3.0.beta2 < 3.0 version int/string bug
- Python implementation:
  - drop Python 2.x support
  - rework as more idiomatic Python 3.x
  - switch to a declarative setuptools config
  - add a PEP 517 pyproject.toml definition
  - reformat the source code using black
  - push the source into a src/ subdirectory
- Add a Rust implementation.

0.2.2 - 2019/01/09
------------------
- Fix the Python command-line tool's use of the standard Python
  JSON module if simplejson is not installed.
- Remove two unnecessary "pass" statements since the functions
  have a doc-string that serves as a null body.

0.2.1 - 2018/11/23
------------------

- Build universal Python wheels.
- Do not require the Python typing module, only use it when it is
  available, e.g. during type checking tests.

0.2.0 - 2018/11/22
------------------

- Reorganize the Python implementation:
  - break it into modules
  - add flake8 and pylint checks
  - add some simple unit tests
  - add type hints

0.1.1 - 2018/05/08
------------------

- Perl 5.10 does not understand the ellipsis unimplemented statement,
  so replace it with a die() statement with an internal error message

0.1.0 - 2018/04/22
------------------

- first public release

Comments: Peter Pentchev <roam@ringlet.net>
